
===========================================================================
Django-keyboard-shortcuts: use the keyboard inside your web project
===========================================================================

**Allow to use the keyboard instead of the mouse inside your web project**

What Is a Keyboard Shortcut?
----------------------------
From Wikipedia: Keyboard shortcuts are typically an alternate means for invoking one or more commands that would otherwise be accessible only through a menu, a pointing device, different levels of a user interface, or via a command console. Keyboard shortcuts generally expedite common operations by reducing input sequences to a few keystrokes, hence the term "shortcut".

Learn more here: http://en.wikipedia.org/wiki/Keyboard_shortcut


Installation
============

There are a few different ways to install keyboard_shortcus:

Using pip
---------
If you have pip install available on your system, just type::

    pip install django-keyboard-shortcuts

If you've already got an old version of keyboard_shortcus, and want to upgrade, use::

    pip install -U django-keyboard-shortcuts

Installing from a directory
---------------------------
If you've obtained a copy of keyboard_shortcus using either Mercurial or a downloadable
archive, you'll need to install the copy you have system-wide. Try running::

    python setup.py develop

If that fails, you don't have ``setuptools`` or an equivalent installed;
either install them, or run::

    python setup.py install


How to use keyboard_shortcus?
=============================

If you have already installed keyboard_shortcus, you must proceed with the
configuration of your project.

Configuration
-------------

First of all you must...

Key and Character Codes
-----------------------
Very helpful pages resources here:

http://www.w3.org/2002/09/tests/keys.html

http://www.quirksmode.org/js/keys.html#t00

http://unixpapa.com/js/key.html

How to test keyboard_shortcus?
==============================

Very simple::

    $ ./manage.py test keyboard_shortcus


Changelog
=========

0.0.4
-----

* now you can add multiple key combinations
* improved tests
* updated the documentation

0.0.3
-----

* included "keyboard_shortcuts/templates *" in MANIFEST.in
* documentation updated
* templatetags and utils are now tested

0.0.2
-----

* added hotkeys templatetag
* added an example project for testing purposes

0.0.1
-----

* initial structure